# Generated by Django 2.1.1 on 2018-12-13 05:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djeddit', '0006_thread_slug'),
    ]

    operations = [
        migrations.AlterField(
            model_name='thread',
            name='locked',
            field=models.BooleanField(blank=True, default=False),
        ),
    ]
